@@ -1,6 +1,6 @@
 /* simple.h
  *
- * Copyright (C) 2008 libvtemm Development Team
+ * Copyright (C) 2008, 2009 libvtemm Development Team
  *
  * This file is part of Terminal Example.
  *
@@ -18,24 +18,25 @@
  * along with Terminal Example.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBVTEMM_EXAMPLE_SIMPLE_H
-#define LIBVTEMM_EXAMPLE_SIMPLE_H
+#ifndef _LIBVTEMM_EXAMPLE_SIMPLE_H_
+#define _LIBVTEMM_EXAMPLE_SIMPLE_H_
 
-#include <gtkmm/window.h>
+#include <gtkmm.h>
 #include <libvtemm/terminal.h>
 
 class Simple : public Gtk::Window
 {
-	public:
-		Simple();
-		virtual ~Simple();
-
-	protected:
-		//Signal handlers:
-		virtual void on_child_exited();
-
-		//Member widgets:
-		Gnome::Vte::Terminal m_terminal;
+public:
+  Simple();
+  virtual ~Simple();
+protected:
+  //Signal handlers:
+  virtual void on_child_exited();
+private:
+  //Member widgets:
+  Gtk::HBox m_box;
+  Gnome::Vte::Terminal m_terminal;
+  Gtk::VScrollbar m_scrollbar;
 };
 
-#endif // LIBVTEMM_EXAMPLE_SIMPLE_H
+#endif // _LIBVTEMM_EXAMPLE_SIMPLE_H_
